@@ -381,6 +381,11 @@ inline void UNUSED(const volatile T &)
 {
 }
 
+// C++11 has stricter requirements for compile-time checks.
+# if __cplusplus < 201103
+#  define constexpr const
+# endif
+
 #endif // __cplusplus
 
 
