@@ -312,6 +312,7 @@
 {'>', CMD_MAP_FIND_DOWNSTAIR},
 {'@', CMD_MAP_FIND_YOU},
 {'\t', CMD_MAP_FIND_PORTAL},
+{'\\', CMD_MAP_FIND_PORTAL},
 {'^', CMD_MAP_FIND_TRAP},
 {'_', CMD_MAP_FIND_ALTAR},
 {'E', CMD_MAP_FIND_EXCLUDED},
@@ -326,6 +327,7 @@
 {'S', CMD_MAP_GOTO_TARGET},
 {',', CMD_MAP_GOTO_TARGET},
 {';', CMD_MAP_GOTO_TARGET},
+{'!', CMD_MAP_ANNOTATE_LEVEL},
 {ESCAPE, CMD_MAP_EXIT_MAP},
 #ifdef CLUA_BINDINGS
 {CONTROL('I'), CMD_AUTOFIGHT},
