@@ -771,7 +771,10 @@ std::string getSpeakString(const std::string &key)
 #ifdef DEBUG_MONSPEAK
     dprf("monster speech lookup for %s", key.c_str());
 #endif
-    return _getRandomisedStr(SpeakDB, key, "", num_replacements);
+    std::string txt = _getRandomisedStr(SpeakDB, key, "", num_replacements);
+    execute_embedded_lua(txt);
+
+    return txt;
 }
 
 /////////////////////////////////////////////////////////////////////////////
@@ -793,7 +796,10 @@ std::string getRandNameString(const std::string &itemtype,
 
 std::string getHelpString(const std::string &topic)
 {
-    return _query_database(HelpDB.get(), topic, false, true);
+    std::string help = _query_database(HelpDB.get(), topic, false, true);
+    if (help.empty())
+        help = "Error! The help for \"" + topic + "\" is missing!";
+    return help;
 }
 
 /////////////////////////////////////////////////////////////////////////////
