@@ -2963,7 +2963,7 @@ void card_effect(card_type which_card, deck_rarity_type rarity,
         if (you.is_undead == US_UNDEAD)
             mpr("You feel rather smug.");
         else
-            set_hunger(500, true);
+            set_hunger(std::min(you.hunger, 500), true);
         break;
 
     case CARD_FEAST:
