@@ -1048,6 +1048,11 @@ void annotate_level()
             li = li2;
     }
 
+    do_annotate(li);
+}
+
+void do_annotate(level_id& li)
+{
     if (!get_level_annotation(li).empty())
     {
         mpr("Current level annotation: " +
@@ -1055,8 +1060,8 @@ void annotate_level()
             MSGCH_PROMPT);
     }
 
-    const std::string prompt = "New level annotation "
-                               "(include '!' for warning): ";
+    const std::string prompt = "New annotation for " + li.describe()
+                               + " (include '!' for warning): ";
 
     char buf[77];
     if (msgwin_get_line_autohist(prompt, buf, sizeof(buf)))
