@@ -1890,9 +1890,6 @@ void level_excursion::go_to(const level_id& next)
     }
 
     you.on_current_level = (level_id::current() == original);
-
-    // Don't let uncommitted writes accumulate.
-    you.save->commit();
 }
 
 level_excursion::~level_excursion()
