@@ -1681,7 +1681,7 @@ std::string scorefile_entry::death_description(death_desc_verbosity verbosity)
         else
         {
             desc += "Succumbed to " + ((death_source_name == "you")
-                      ? "your own" : apostrophise(death_source_name)) + " "
+                      ? "their own" : apostrophise(death_source_name)) + " "
                     + (auxkilldata.empty()? "poison" : auxkilldata);
         }
         break;
@@ -1699,7 +1699,7 @@ std::string scorefile_entry::death_description(death_desc_verbosity verbosity)
         {
             snprintf(scratch, sizeof(scratch), "Engulfed by %s%s %s",
                 death_source_name.empty() ? "a" :
-                  death_source_name == "you" ? "own" :
+                  death_source_name == "you" ? "their own" :
                   apostrophise(death_source_name).c_str(),
                 death_source_name.empty() ? " cloud of" : "",
                 auxkilldata.c_str());
@@ -2407,19 +2407,20 @@ void mark_milestone(const std::string &type,
 
     const std::string milestone_file =
         (Options.save_dir + "milestones" + crawl_state.game_type_qualifier());
+    const scorefile_entry se(0, 0, KILL_MISC, NULL);
+    se.set_base_xlog_fields();
+    xlog_fields xl = se.get_fields();
+    if (report_origin_level)
+        xl.add_field("oplace", "%s",
+                     current_level_parent().describe().c_str());
+    xl.add_field("time", "%s",
+                 make_date_string(se.get_death_time()).c_str());
+    xl.add_field("type", "%s", type.c_str());
+    xl.add_field("milestone", "%s", milestone.c_str());
+    const std::string xlog_line = xl.xlog_line();
     if (FILE *fp = lk_open("a", milestone_file))
     {
-        const scorefile_entry se(0, 0, KILL_MISC, NULL);
-        se.set_base_xlog_fields();
-        xlog_fields xl = se.get_fields();
-        if (report_origin_level)
-            xl.add_field("oplace", "%s",
-                         current_level_parent().describe().c_str());
-        xl.add_field("time", "%s",
-                     make_date_string(se.get_death_time()).c_str());
-        xl.add_field("type", "%s", type.c_str());
-        xl.add_field("milestone", "%s", milestone.c_str());
-        fprintf(fp, "%s\n", xl.xlog_line().c_str());
+        fprintf(fp, "%s\n", xlog_line.c_str());
         lk_close(fp, "a", milestone_file);
     }
 #endif // DGL_MILESTONES
