@@ -680,7 +680,7 @@ spret_type vampiric_drain(int pow, monster* mons, bool fail)
 
     hp_gain /= 2;
 
-    if (hp_gain && !mons_was_summoned)
+    if (hp_gain && !mons_was_summoned && !you.duration[DUR_DEATHS_DOOR])
     {
         mpr("You feel life coursing into your body.");
         inc_hp(hp_gain);
