@@ -1082,15 +1082,7 @@ static void _dgn_check_terrain_player(const coord_def pos)
         return;
 
     if (you.can_pass_through(pos))
-    {
-        // If the monster can't stay submerged in the new terrain and
-        // there aren't any adjacent squares where it can stay
-        // submerged then move it.
-        monster* mon = monster_at(pos);
-        if (mon && !mon->submerged())
-            monster_teleport(mon, true, false);
         move_player_to_grid(pos, false, true);
-    }
     else
         you_teleport_now(true, false);
 }
@@ -1452,23 +1444,30 @@ bool slide_feature_over(const coord_def &src, coord_def preferred_dest,
 
 // Returns true if we manage to scramble free.
 bool fall_into_a_pool(const coord_def& entry, bool allow_shift,
-                       dungeon_feature_type terrain)
+                      dungeon_feature_type terrain)
 {
     bool escape = false;
     bool clinging = false;
     coord_def empty;
 
-    if (species_likes_water(you.species) && terrain == DNGN_DEEP_WATER
-        && !form_likes_water() && !you.transform_uncancellable)
+    if (terrain == DNGN_DEEP_WATER)
     {
-        // These can happen when we enter deep water directly -- bwr
-        emergency_untransform();
-        return (false);
-    }
+        if (beogh_water_walk())
+            return (false);
 
-    // sanity check
-    if (terrain != DNGN_LAVA && (beogh_water_walk() || you.can_swim()))
-        return (false);
+        if (species_likes_water(you.species) || form_likes_water())
+        {
+            // These can happen when we enter deep water directly. - bwr
+            if (form_likes_water())
+                return (false);
+
+            if (!form_likes_water() && !you.transform_uncancellable)
+            {
+                emergency_untransform();
+                return (false);
+            }
+        }
+    }
 
     mprf("You fall into the %s!",
          (terrain == DNGN_LAVA)       ? "lava" :
@@ -1508,8 +1507,9 @@ bool fall_into_a_pool(const coord_def& entry, bool allow_shift,
         expose_player_to_element(BEAM_LAVA, 14);
     }
 
-    // a distinction between stepping and falling from you.duration[DUR_LEVITATION]
-    // prevents stepping into a thin stream of lava to get to the other side.
+    // A distinction between stepping and falling from
+    // you.duration[DUR_LEVITATION] prevents stepping into a thin stream
+    // of lava to get to the other side.
     if (scramble())
     {
         if (allow_shift)
@@ -1520,17 +1520,15 @@ bool fall_into_a_pool(const coord_def& entry, bool allow_shift,
         }
         else
         {
-            // back out the way we came in, if possible
+            // Back out the way we came in, if possible.
             if (grid_distance(you.pos(), entry) == 1
                 && !monster_at(entry))
             {
                 escape = true;
                 empty = entry;
             }
-            else  // zero or two or more squares away, with no way back
-            {
+            else  // Zero or two or more squares away, with no way back.
                 escape = false;
-            }
         }
     }
     else
