@@ -410,9 +410,7 @@ void TilesFramework::pop_prefix(const std::string& suffix)
         m_prefixes.pop_back();
     }
     else
-    {
-        write_message(suffix.c_str());
-    }
+        write_message("%s", suffix.c_str());
 }
 
 bool TilesFramework::prefix_popped()
@@ -825,6 +823,11 @@ void TilesFramework::_send_map(bool force_full)
         {
             coord_def gc(x, y);
 
+            if (!is_dirty(gc) && !force_full)
+                continue;
+            else
+                mark_clean(gc);
+
             if (m_origin.equals(-1, -1))
                 m_origin = gc;
 
@@ -959,6 +962,8 @@ void TilesFramework::load_dungeon(const crawl_view_buffer &vbuf,
                 draw_cell(cell, grid, false, m_next_flash_colour);
                 cell->tile.flv = env.tile_flv(grid);
                 pack_cell_overlays(grid, &(cell->tile));
+
+                mark_dirty(grid);
             }
         }
 
@@ -980,6 +985,8 @@ void TilesFramework::load_dungeon(const crawl_view_buffer &vbuf,
             *cell = ((const screen_cell_t *) vbuf)[x + vbuf.size().x * y];
             cell->tile.flv = env.tile_flv(grid);
             pack_cell_overlays(grid, &(cell->tile));
+
+            mark_dirty(grid);
         }
 
     m_next_gc = gc;
@@ -1182,6 +1189,8 @@ void TilesFramework::update_minimap(const coord_def& gc)
     draw_cell(cell, gc, false, m_next_flash_colour);
     cell->tile.flv = env.tile_flv(gc);
     pack_cell_overlays(gc, &(cell->tile));
+
+    mark_dirty(gc);
 }
 
 void TilesFramework::clear_minimap()
